==> jsonapi-server-4.0.0.tgz: package/CHANGELOG.md <==
- 2017-11-03 - v4.0.0
- 2017-11-03 - Return error when a response item does not validate.
- 2017-11-03 - Remove Node.js 4 support.
- 2017-10-21 - v3.2.2
- 2017-10-21 - Report coverage with Coveralls.
- 2017-10-21 - Modernise script.
- 2017-09-23 - v3.2.1
- 2017-09-23 - Fix packaging.
- 2017-09-19 - v3.2.0
- 2017-09-19 - Node.js 8 support.
- 2017-09-14 - v3.1.0
- 2017-09-14 - Improved Swagger 2.0 configuration.
- 2017-09-14 - Correct sorting of date properties.
- 2017-09-14 - Fix bug when trying to detect arrays during Joi validation.
- 2017-09-14 - Fix bug for some requests with both `include` and `fields`.
- 2017-07-14 - v3.0.3
- 2017-07-14 - v3.0.2
- 2017-07-14 - v3.0.1
- 2017-07-14 - Update dependencies.
- 2017-06-01 - v3.0.0
- 2017-06-01 - Use `Buffer.from` instead of deprecated `new Buffer` which only supports Node.js >= 4.5.0 requiring a major version upgrade for SemVer compliance
- 2017-06-01 - Fix GraphQL updates
- 2017-02-06 - Ability to skip graphiql modelling
- 2017-02-06 - v2.3.2
- 2017-02-06 - Fix bug when filtering with comma separated list
- 2017-02-06 - Ability to skip graphiql modelling
- 2017-01-05 - v2.3.1
- 2017-01-05 - Fix bug when calculating the pagination offsets for last page
- 2017-01-05 - Improve contributing doc
- 2016-12-15 - v2.3.0
- 2016-12-15 - Validate resource schema before starting the server
- 2016-12-08 - v2.2.1
- 2016-12-08 - Prefer client generated ID's for newly created resources
- 2016-12-08 - ChainHandler supports .close()
- 2016-12-08 - Better documentation around handler.close
- 2016-12-08 - Bug fix when calling server.close with a custom router
- 2016-11-07 - v2.2.0
- 2016-11-07 - Adding polymorphic relationships
- 2016-11-07 - Correctly handle validation errors when including non-existant resources
- 2016-11-07 - Added Array Joi type for GraphQL
- 2016-09-29 - v2.1.0
- 2016-09-29 - Enable injection of an Express Router
- 2016-09-29 - v2.0.2
- 2016-09-29 - Better Joi to GraphQL type conversion
- 2016-09-29 - v2.0.1
- 2016-09-29 - Adding use-strict to all files
- 2016-09-29 - v2.0.0
- 2016-09-28 - Bumped all dependencies to latest
- 2016-09-28 - Removed hiphens from list of allowed characters in names
- 2016-09-28 - Converted to ES6
- 2016-09-28 - Converted to eslint:standard
- 2016-09-28 - Enabled GraphQL
- 2016-09-20 - v1.17.0
- 2016-09-20 - Remove metrics listeners on server.close()
- 2016-09-20 - Dynamic swagger.json based on handler capabilities
- 2016-09-20 - Dynamic metadata in body of responses
- 2016-09-20 - Comma separated filter values
- 2016-09-20 - Option to override base urls in links
- 2016-09-08 - v1.16.1
- 2016-09-08 - Improving ChainHandler for synchronous functions
- 2016-09-08 - Improving ChainHandler for 'after' functions
- 2016-09-08 - v1.16.0
- 2016-09-07 - Accept initilize with a 'z'
- 2016-09-07 - Implemented new ChainHandler
- 2016-08-07 - Additional validation when defining primary relationships
- 2016-07-06 - v1.15.4
- 2016-07-06 - Prevent express from appending the charset to the content-type header
- 2016-07-06 - v1.15.3
- 2016-07-06 - Provide text error to help debug HTTP 415s
- 2016-07-06 - v1.15.2
- 2016-07-06 - CORS headers are now applier further up the middleware chain
- 2016-07-05 - v1.15.1
- 2016-07-05 - Fixed bug when deleting singular relationships via deep urls
- 2016-07-05 - Added warning messages to test suite to warn when handlers don't filter
- 2016-06-28 - v1.15.0
- 2016-06-28 - Scrap sub-millisecond accuracy on metrics
- 2016-06-27 - v1.14.0
- 2016-06-27 - Enabled application metrics
- 2016-06-22 - v1.13.0
- 2016-06-22 - Fixed bug when setting singular relationships via deep urls
- 2016-06-22 - Enable access to expressJS instance
- 2016-06-09 - v1.12.0
- 2016-06-09 - MemoryHandler clones all objects
- 2016-06-02 - v1.11.0
- 2016-06-02 - Error when interacting with broken resources
- 2016-06-02 - Unable to patch relationships on resources with required attributes
- 2016-05-31 - v1.10.0
- 2016-05-31 - Export module version so data stores can check for a minimum required version
- 2016-05-27 - v1.9.0
- 2016-05-27 - Make parsed and validated filter available in request for handlers
- 2016-05-24 - v1.8.0
- 2016-05-24 - HTTPS support
- 2016-05-24 - v1.7.0
- 2016-05-24 - Resolves swagger validation errors
- 2016-05-24 - Generated swagger doc adheres to required() fields
- 2016-05-16 - v1.6.0
- 2016-05-16 - Enable authentication errors
- 2016-05-16 - Avoid the HTTP stack for inclusions
- 2016-05-16 - Fix crash when opt-ing out of resource operations
- 2016-05-05 - v1.5.0
- 2016-05-05 - Allow overriding debug output functions
- 2016-04-27 - Static code analysis with Flow and JSCPD
- 2016-04-22 - v1.4.0
- 2016-04-22 - Return all validation errors
- 2016-02-16 - v1.3.3
- 2016-02-16 - Filtering falsy boolean values
- 2016-02-16 - v1.3.2
- 2016-02-16 - Correctly filter by non-string attributes
- 2016-02-10 - v1.3.1
- 2016-02-10 - Correctly handle missing to-one related resources
- 2016-01-25 - v1.3.0
- 2016-01-25 - Aggressive cache-expiry headers by default
- 2016-01-21 - v1.2.0
- 2016-01-21 - Set better default CORS headers
- 2016-01-11 - v1.1.0
- 2016-01-11 - Error hard and fast when incorrectly defining foreign relations
- 2016-01-11 - Updating dependencies
- 2016-01-11 - Sanitise input + output with Joi
- 2016-01-11 - Big documentation improvements
- 2015-12-31 - v1.0.5
- 2015-12-31 - Set Location header correctly when creating resources
- 2015-12-30 - v1.0.4
- 2015-12-30 - Enable path-less API
- 2015-12-17 - v1.0.3
- 2015-12-17 - Filter won't match undefined properties anymore
- 2015-12-17 - Don't pass on content-length HTTP headers on inclusion requests
- 2015-12-11 - v1.0.2
- 2015-12-11 - Test harness improvements
- 2015-12-10 - v1.0.1
- 2015-12-10 - Correcting v8-profiler dependency
- 2015-12-10 - v1.0.0
- 2015-12-10 - Inclusion bug fixes
- 2015-12-10 - Use filter[] instead of relationships[]
- 2015-12-10 - Move to lodash
- 2015-12-10 - CPU profiling
- 2015-12-08 - Pagination support
- 2015-12-07 - Efficient inclusions
- 2015-12-05 - Tooling improvements
- 2015-12-03 - Top level jsonapi blocks
- 2015-11-25 - v0.16.0
- 2015-11-25 - Validation around handlers behaviour
- 2015-11-25 - Debugging functionality
- 2015-11-25 - Automatic Swagger Generation
- 2015-11-19 - v0.15.2
- 2015-11-19 - Validate filter params before handing over to resourceHandler.search
- 2015-11-18 - v0.15.1
- 2015-11-18 - Updated documentation
- 2015-11-18 - v0.15.0
- 2015-11-18 - Rename MockHandler to MemoryHandler
- 2015-11-17 - v0.14.0
- 2015-11-17 - Handlers are now objects instead of modules
- 2015-11-17 - v0.13.1
- 2015-11-17 - Additional error handling for foreign relation lookup
- 2015-11-12 - v0.13.0
- 2015-11-12 - Handlers readiness check
- 2015-11-11 - v0.12.2
- 2015-11-11 - Blacklist some HTTP headers we dont want to pass onwards
- 2015-11-11 - v0.12.1
- 2015-11-11 - Correctly build related URLs when using HTTPS
- 2015-11-10 - v0.12.0
- 2015-11-10 - Additional error detail on 403 and 404
- 2015-11-10 - Additional error handling for foreign relation lookup
- 2015-11-09 - Creating resources gives a 201 CREATED
- 2015-11-09 - Pass around headers on inclusion requests
- 2015-11-09 - Ignore non-js routes within the example app
- 2015-11-06 - v0.11.0
- 2015-11-06 - Improve resource-update validation
- 2015-11-05 - v0.10.0
- 2015-09-27 - Always respond with absolute URLs
- 2015-09-27 - v0.9.0
- 2015-09-27 - Improve validation when updating a relationship
- 2015-09-25 - Stricter handling of HTTP Content-Type headers
- 2015-09-25 - Stricter handling of HTTP Accept headers
- 2015-09-25 - Validate attribute names
- 2015-09-25 - Enable basic authentication
- 2015-09-25 - Updating dependencies
- 2015-09-25 - Adding cookies to Request objects
- 2015-09-25 - Enabling meta blocks on Resources and Relations
- 2015-07-13 - v0.8.0
- 2015-07-13 - Updating dependencies to latest stable releases
- 2015-07-13 - Split out documentation into more manageable chunks
- 2015-07-12 - Split out Joi modifications into separate file
- 2015-07-12 - Split postProcessing into smaller modules
- 2015-07-12 - v0.7.0
- 2015-07-11 - Code Complexity tool via npm-run-complexity
- 2015-07-08 - Added additional info to relation metadata
- 2015-07-06 - Handle 404s and allow logging for uncaught exceptions
- 2015-07-05 - Allow user to implement their own error logging
- 2015-07-03 - Separating out route handlers into separate files
- 2015-07-03 - Refactoring handlers to improve readability
- 2015-06-29 - Initial release

==> jsonapi-server-4.2.0.tgz: package/CHANGELOG.md <==
- 2018-01-31 - v4.2.0
- 2018-01-31 - Support setting limit of query string parameters through a configuration property.
- 2018-01-31 - Support setting `bodyParser.json` option through a configuration property.
- 2018-01-31 - Fix CRUD operation detection when using chain handlers.
- 2017-12-11 - v4.1.2
- 2017-12-11 - Fix broken response test resource to enable integration with data store handlers.
- 2017-11-15 - v4.1.1
- 2017-11-15 - Downgrade Joi to a version supported by Node.js v6.
- 2017-11-15 - Force `engine-strict=true` when running npm.
- 2017-11-14 - v4.1.0
- 2017-11-14 - New configuration option to disable automatic id generation.
- 2017-11-14 - Update GraphQL dependencies to latest versions.
- 2017-11-14 - Remove yarn lockfile.
- 2017-11-03 - v4.0.0
- 2017-11-03 - Return error when a response item does not validate.
- 2017-11-03 - Remove Node.js 4 support.
- 2017-10-21 - v3.2.2
- 2017-10-21 - Report coverage with Coveralls.
- 2017-10-21 - Modernise script.
- 2017-09-23 - v3.2.1
- 2017-09-23 - Fix packaging.
- 2017-09-19 - v3.2.0
- 2017-09-19 - Node.js 8 support.
- 2017-09-14 - v3.1.0
- 2017-09-14 - Improved Swagger 2.0 configuration.
- 2017-09-14 - Correct sorting of date properties.
- 2017-09-14 - Fix bug when trying to detect arrays during Joi validation.
- 2017-09-14 - Fix bug for some requests with both `include` and `fields`.
- 2017-07-14 - v3.0.3
- 2017-07-14 - v3.0.2
- 2017-07-14 - v3.0.1
- 2017-07-14 - Update dependencies.
- 2017-06-01 - v3.0.0
- 2017-06-01 - Use `Buffer.from` instead of deprecated `new Buffer` which only supports Node.js >= 4.5.0 requiring a major version upgrade for SemVer compliance
- 2017-06-01 - Fix GraphQL updates
- 2017-02-06 - Ability to skip graphiql modelling
- 2017-02-06 - v2.3.2
- 2017-02-06 - Fix bug when filtering with comma separated list
- 2017-02-06 - Ability to skip graphiql modelling
- 2017-01-05 - v2.3.1
- 2017-01-05 - Fix bug when calculating the pagination offsets for last page
- 2017-01-05 - Improve contributing doc
- 2016-12-15 - v2.3.0
- 2016-12-15 - Validate resource schema before starting the server
- 2016-12-08 - v2.2.1
- 2016-12-08 - Prefer client generated ID's for newly created resources
- 2016-12-08 - ChainHandler supports .close()
- 2016-12-08 - Better documentation around handler.close
- 2016-12-08 - Bug fix when calling server.close with a custom router
- 2016-11-07 - v2.2.0
- 2016-11-07 - Adding polymorphic relationships
- 2016-11-07 - Correctly handle validation errors when including non-existant resources
- 2016-11-07 - Added Array Joi type for GraphQL
- 2016-09-29 - v2.1.0
- 2016-09-29 - Enable injection of an Express Router
- 2016-09-29 - v2.0.2
- 2016-09-29 - Better Joi to GraphQL type conversion
- 2016-09-29 - v2.0.1
- 2016-09-29 - Adding use-strict to all files
- 2016-09-29 - v2.0.0
- 2016-09-28 - Bumped all dependencies to latest
- 2016-09-28 - Removed hiphens from list of allowed characters in names
- 2016-09-28 - Converted to ES6
- 2016-09-28 - Converted to eslint:standard
- 2016-09-28 - Enabled GraphQL
- 2016-09-20 - v1.17.0
- 2016-09-20 - Remove metrics listeners on server.close()
- 2016-09-20 - Dynamic swagger.json based on handler capabilities
- 2016-09-20 - Dynamic metadata in body of responses
- 2016-09-20 - Comma separated filter v 1 successful check
alues
- 2016-09-20 - Option to override base urls in links
- 2016-09-08 - v1.16.1
- 2016-09-08 - Improving ChainHandler for synchronous functions
- 2016-09-08 - Improving ChainHandler for 'after' functions
- 2016-09-08 - v1.16.0
- 2016-09-07 - Accept initilize with a 'z'
- 2016-09-07 - Implemented new ChainHandler
- 2016-08-07 - Additional validation when defining primary relationships
- 2016-07-06 - v1.15.4
- 2016-07-06 - Prevent express from appending the charset to the content-type header
- 2016-07-06 - v1.15.3
- 2016-07-06 - Provide text error to help debug HTTP 415s
- 2016-07-06 - v1.15.2
- 2016-07-06 - CORS headers are now applier further up the middleware chain
- 2016-07-05 - v1.15.1
- 2016-07-05 - Fixed bug when deleting singular relationships via deep urls
- 2016-07-05 - Added warning messages to test suite to warn when handlers don't filter
- 2016-06-28 - v1.15.0
- 2016-06-28 - Scrap sub-millisecond accuracy on metrics
- 2016-06-27 - v1.14.0
- 2016-06-27 - Enabled application metrics
- 2016-06-22 - v1.13.0
- 2016-06-22 - Fixed bug when setting singular relationships via deep urls
- 2016-06-22 - Enable access to expressJS instance
- 2016-06-09 - v1.12.0
- 2016-06-09 - MemoryHandler clones all objects
- 2016-06-02 - v1.11.0
- 2016-06-02 - Error when interacting with broken resources
- 2016-06-02 - Unable to patch relationships on resources with required attributes
- 2016-05-31 - v1.10.0
- 2016-05-31 - Export module version so data stores can check for a minimum required version
- 2016-05-27 - v1.9.0
- 2016-05-27 - Make parsed and validated filter available in request for handlers
- 2016-05-24 - v1.8.0
- 2016-05-24 - HTTPS support
- 2016-05-24 - v1.7.0
- 2016-05-24 - Resolves swagger validation errors
- 2016-05-24 - Generated swagger doc adheres to required() fields
- 2016-05-16 - v1.6.0
- 2016-05-16 - Enable authentication errors
- 2016-05-16 - Avoid the HTTP stack for inclusions
- 2016-05-16 - Fix crash when opt-ing out of resource operations
- 2016-05-05 - v1.5.0
- 2016-05-05 - Allow overriding debug output functions
- 2016-04-27 - Static code analysis with Flow and JSCPD
- 2016-04-22 - v1.4.0
- 2016-04-22 - Return all validation errors
- 2016-02-16 - v1.3.3
- 2016-02-16 - Filtering falsy boolean values
- 2016-02-16 - v1.3.2
- 2016-02-16 - Correctly filter by non-string attributes
- 2016-02-10 - v1.3.1
- 2016-02-10 - Correctly handle missing to-one related resources
- 2016-01-25 - v1.3.0
- 2016-01-25 - Aggressive cache-expiry headers by default
- 2016-01-21 - v1.2.0
- 2016-01-21 - Set better default CORS headers
- 2016-01-11 - v1.1.0
- 2016-01-11 - Error hard and fast when incorrectly defining foreign relations
- 2016-01-11 - Updating dependencies
- 2016-01-11 - Sanitise input + output with Joi
- 2016-01-11 - Big documentation improvements
- 2015-12-31 - v1.0.5
- 2015-12-31 - Set Location header correctly when creating resources
- 2015-12-30 - v1.0.4
- 2015-12-30 - Enable path-less API
- 2015-12-17 - v1.0.3
- 2015-12-17 - Filter won't match undefined properties anymore
- 2015-12-17 - Don't pass on content-length HTTP headers on inclusion requests
- 2015-12-11 - v1.0.2
- 2015-12-11 - Test harness improvements
- 2015-12-10 - v1.0.1
- 2015-12-10 - Correcting v8-profiler dependency
- 2015-12-10 - v1.0.0
- 2015-12-10 - Inclusion bug fixes
- 2015-12-10 - Use filter[] instead of relationships[]
- 2015-12-10 - Move to lodash
- 2015-12-10 - CPU profiling
- 2015-12-08 - Pagination support
- 2015-12-07 - Efficient inclusions
- 2015-12-05 - Tooling improvements
- 2015-12-03 - Top level jsonapi blocks
- 2015-11-25 - v0.16.0
- 2015-11-25 - Validation around handlers behaviour
- 2015-11-25 - Debugging functionality
- 2015-11-25 - Automatic Swagger Generation
- 2015-11-19 - v0.15.2
- 2015-11-19 - Validate filter params before handing over to resourceHandler.search
- 2015-11-18 - v0.15.1
- 2015-11-18 - Updated documentation
- 2015-11-18 - v0.15.0
- 2015-11-18 - Rename MockHandler to MemoryHandler
- 2015-11-17 - v0.14.0
- 2015-11-17 - Handlers are now objects instead of modules
- 2015-11-17 - v0.13.1
- 2015-11-17 - Additional error handling for foreign relation lookup
- 2015-11-12 - v0.13.0
- 2015-11-12 - Handlers readiness check
- 2015-11-11 - v0.12.2
- 2015-11-11 - Blacklist some HTTP headers we dont want to pass onwards
- 2015-11-11 - v0.12.1
- 2015-11-11 - Correctly build related URLs when using HTTPS
- 2015-11-10 - v0.12.0
- 2015-11-10 - Additional error detail on 403 and 404
- 2015-11-10 - Additional error handling for foreign relation lookup
- 2015-11-09 - Creating resources gives a 201 CREATED
- 2015-11-09 - Pass around headers on inclusion requests
- 2015-11-09 - Ignore non-js routes within the example app
- 2015-11-06 - v0.11.0
- 2015-11-06 - Improve resource-update validation
- 2015-11-05 - v0.10.0
- 2015-09-27 - Always respond with absolute URLs
- 2015-09-27 - v0.9.0
- 2015-09-27 - Improve validation when updating a relationship
- 2015-09-25 - Stricter handling of HTTP Content-Type headers
- 2015-09-25 - Stricter handling of HTTP Accept headers
- 2015-09-25 - Validate attribute names
- 2015-09-25 - Enable basic authentication
- 2015-09-25 - Updating dependencies
- 2015-09-25 - Adding cookies to Request objects
- 2015-09-25 - Enabling meta blocks on Resources and Relations
- 2015-07-13 - v0.8.0
- 2015-07-13 - Updating dependencies to latest stable releases
- 2015-07-13 - Split out documentation into more manageable chunks
- 2015-07-12 - Split out Joi modifications into separate file
- 2015-07-12 - Split postProcessing into smaller modules
- 2015-07-12 - v0.7.0
- 2015-07-11 - Code Complexity tool via npm-run-complexity
- 2015-07-08 - Added additional info to relation metadata
- 2015-07-06 - Handle 404s and allow logging for uncaught exceptions
- 2015-07-05 - Allow user to implement their own error logging
- 2015-07-03 - Separating out route handlers into separate files
- 2015-07-03 - Refactoring handlers to improve readability
- 2015-06-29 - Initial release
